@@ -21,15 +21,17 @@ use ntapi::{
     },
 };
 use std::{
-    ffi::{c_void, CStr},
+    ffi::{c_void, CStr, OsString},
+    os::windows::prelude::OsStrExt,
+    os::windows::prelude::*,
     path::Path,
     pin::Pin,
     ptr,
     ptr::null_mut,
 };
-use tonic::transport::Channel;
 #[cfg(feature = "tls")]
 use tonic::transport::Certificate;
+use tonic::transport::Channel;
 #[cfg(feature = "tls")]
 use tonic::transport::ClientTlsConfig;
 use winapi::{
@@ -559,21 +561,35 @@ impl<'a> PortableExecutable<'a> {
         // first make sure we got all of the required functions
         let mut file = MappedFile::load(path)?;
         let path = Path::new(path);
-        let file_name = path
+        let file_name: Vec<u16> = path
             .file_name()
-            .ok_or_else(|| std::io::Error::from_raw_os_error(ERROR_FILE_NOT_FOUND as i32))?;
-        let file_path = path.canonicalize()?;
+            .ok_or_else(|| std::io::Error::from_raw_os_error(ERROR_FILE_NOT_FOUND as i32))?
+            .encode_wide()
+            .chain(std::iter::once(0))
+            .collect();
+        // remove the "extended length path syntax"
+        let file_path: Vec<u16> = path
+            .canonicalize()?
+            .as_os_str()
+            .encode_wide()
+            .skip(4)
+            .chain(std::iter::once(0))
+            .collect();
         debug!(
             "Loading {} at path {}",
-            file_name.to_string_lossy(),
-            file_path.to_string_lossy()
+            OsString::from_wide(&file_name[..])
+                .as_os_str()
+                .to_string_lossy(),
+            OsString::from_wide(&file_path[..])
+                .as_os_str()
+                .to_string_lossy()
         );
         let (nt_headers, section_headers) = PortableExecutable::load_headers(&mut file)?;
         let entry_point = PortableExecutable::load_entry_point(&mut file, nt_headers)?;
         let mut pe = PortableExecutable {
             file,
-            file_name: to_wide(&file_name.to_string_lossy()),
-            file_path: to_wide(&file_path.to_string_lossy()),
+            file_name,
+            file_path,
             nt_headers,
             section_headers,
             entry_point,
@@ -905,7 +921,9 @@ mod test {
     lazy_static! {
         static ref NT_CONTEXT: NtContext<'static> = Runtime::new()
             .unwrap()
-            .block_on(NtContext::resolve_local(&OffsetHandler::new("test/cache.json").unwrap()))
+            .block_on(NtContext::resolve_local(
+                &OffsetHandler::new("test/cache.json").unwrap()
+            ))
             .unwrap();
     }
 
@@ -1040,9 +1058,10 @@ mod test {
 
     #[tokio::test]
     #[serial]
-    #[cfg(target = "tls")]
+    #[cfg(all(feature = "tls", feature = "server"))]
     async fn tls_server() {
-        use std::net::SocketAddrV4;
+        use crate::server::Server;
+        use std::net::{Ipv4Addr, SocketAddr, SocketAddrV4};
         use tonic::transport::Identity;
         // start the server
         let endpoint = SocketAddr::V4(SocketAddrV4::new(Ipv4Addr::new(127, 0, 0, 1), 44443));
